## This is just to practice creating packages

import numpy as np

def standard_deviation(x):
    ary =  np.array(x).flatten()
    n = len(ary)
    mean = sum(ary) / n
    ssq = sum((x_i-mean)**2 for x_i in ary)
    stdev = (ssq/n)**0.5
    return(stdev)



# importing :
from sahirPyStd import standard_deviation as s_d

# Usage - standard_error(x)
# Input - x: array of doubles
# Output - standard error of input array x
# Example = standard_error([1,2,3])
standard_error = lambda x: s_d.standard_deviation(x)/len(x)**0.5



from distutils.core import setup

setup(
    name = "sahir_py_std",
    version = "0.5",
    packages=['sahirPyStd'],
    license='Creative Commons Attribution-Noncommercial-Share Alike license',
    long_description=open('README.txt').read()
)
